@@ -1984,3 +1984,30 @@ class VariableClBuilderContainerDataPath(ImagePathHelper, Variable):
 
     prefix = "lxc-"
 
+class VariableClBuilderWithBdepsSet(Variable):
+    """
+    Добавление --with-bdeps при вызове emerge
+    """
+    type = Variable.Types.Tristate
+
+    def get(self):
+        dv = self.Get('cl_builder_linux_datavars')
+        if dv:
+            return dv.Get('cl_update_with_bdeps_set')
+        return Variable.Auto
+
+
+class VariableClBuilderWithBdepsOptSet(Variable):
+    """
+    Добавление --with-bdeps при вызове emerge (опция)
+    """
+    type = Variable.Types.Tristate
+    opt = ["--with-bdeps"]
+    metavalue = "ON/OFF/AUTO"
+
+    def init(self):
+        self.help = _("save packages used during build")
+        self.label = _("Save packages used during build")
+
+    def get(self):
+        return self.Get('cl_builder_with_bdeps_set')
