@@ -178,7 +178,8 @@ class Wsdl(WsdlBase):
                     _("Update the Build"),
                     normal=('cl_builder_prepared_id',
                             'cl_builder_binhost_stable_opt_set',
-                            'update.cl_update_binhost_recheck_set',),
+                            'update.cl_update_binhost_recheck_set',
+                            'cl_builder_with_bdeps_opt_set',),
                     expert=(
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
@@ -229,6 +230,7 @@ class Wsdl(WsdlBase):
                         'cl_builder_prepared_id',
                         'cl_builder_binhost_stable_opt_set',
                         'update.cl_update_binhost_recheck_set',
+                        'cl_builder_with_bdeps_opt_set',
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
                         'update.cl_update_pretend_set',
